# SnekRay
![example branch parameter](https://github.com/vextor22/snekray/actions/workflows/python-package.yml/badge.svg?branch=main)


Python implementation of "The Ray Tracer Challenge"

For testing:
```
python3 -m venv venv
source venv/bin/activate
pip install -r requirements.txt
dotenv run -- python example.py
```
